| ctm | R Documentation |
Specification of conditional transformation models
ctm(response, interacting = NULL, shifting = NULL, scaling = NULL,
scale_shift = FALSE, data = NULL,
todistr = c("Normal", "Logistic", "MinExtrVal", "MaxExtrVal",
"Exponential", "Laplace", "Cauchy"),
sumconstr = inherits(interacting, c("formula", "formula_basis")), ...)
has_scale(object)
response |
a basis function, ie, an object of class |
interacting |
a basis function, ie, an object of class |
shifting |
a basis function, ie, an object of class |
scaling |
a basis function, ie, an object of class |
scale_shift |
a logical choosing between two different model types
in the presence of a |
data |
either a |
todistr |
a character vector describing the distribution to be transformed |
sumconstr |
a logical indicating if sum constraints shall be applied |
object |
an object of class |
... |
arguments to |
This function only specifies the model which can then be fitted using
mlt. The shift term is positive by default. All arguments except
response can be missing (in this case an unconditional distribution
is estimated). \bibcitetmlt::Hothorn:Moest:Buehlmann:2017 explain the model class.
Possible choices of the distributions the model transforms to (the inverse
link functions F_Z) include the
standard normal ("Normal"), the standard logistic
("Logistic"), the standard minimum extreme value
("MinExtrVal", also known as Gompertz distribution), and the
standard maximum extreme value ("MaxExtrVal", also known as Gumbel
distribution) distributions. The exponential distribution
("Exponential") can be used to fit Aalen additive hazard models.
Laplace and Cauchy distributions are also available.
Shift-scale models \bibcitepmlt::Siegfried_Kook_Hothorn_2023 of the form
P(Y \le y \mid X = x) = F_Z(\sqrt{\exp(s(x)^\top \gamma)} [(a(y) \otimes b(x))^\top \vartheta] + d(x)^\top \beta)
(scale_shift = FALSE) or
P(Y \le y \mid X = x) = F_Z(\sqrt{\exp(s(x)^\top \gamma)} [(a(y) \otimes b(x))^\top \vartheta + d(x)^\top \beta])
(scale_shift = TRUE)
with bases a(y) (response), b(x) (interacting),
d(x) (shifting), and s(x) (scaling) can be
specified as well.
An object of class ctm; and a logical is returned by
has_scale when a scale term is present in object.
*
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.