| mmlt | R Documentation |
Conditional transformation models for multivariate continuous, discrete, or a mix of continuous and discrete outcomes
mmlt(..., formula = ~ 1, data, conditional = FALSE,
theta = NULL, fixed = NULL, scaleparm = FALSE,
optim = mltoptim(hessian = TRUE), ### provides hessian
args = list(seed = 1, M = 1000),
dofit = TRUE, domargins = TRUE)
## S3 method for class 'cmmlt'
coef(object, newdata,
type = c("all", "conditional",
"Lambda", "Omega", "Lambdainv", "Omegainv",
"Precision", "PartialCorr", "Sigma", "Corr",
"Spearman", "Kendall"), fixed = TRUE,
...)
## S3 method for class 'mmmlt'
coef(object, newdata,
type = c("all", "marginal",
"Lambda", "Omega", "Lambdainv", "Omegainv",
"Precision", "PartialCorr", "Sigma", "Corr",
"Spearman", "Kendall"), fixed = TRUE,
...)
## S3 method for class 'mmlt'
predict(object, newdata, margins = 1:J,
type = c("trafo", "distribution", "survivor", "density", "hazard"),
log = FALSE, args = object$args, ...)
## S3 method for class 'mmlt'
simulate(object, nsim = 1L, seed = NULL, newdata, K = 50, ...)
## S3 method for class 'mmlt'
residuals(object, parm = coef(object, fixed = FALSE),
w = NULL, newdata = NULL, ...)
... |
marginal transformation models, one for each response, for
|
formula |
a model formula describing a model for the dependency
structure via the lambda parameters. The default is set to |
data |
a data.frame. |
conditional |
logical; parameters are defined conditionally (only
possible when all models are probit models). This is the default as
described by Klein et al. (2022). If |
theta |
an optional vector of starting values. |
fixed |
an optional named numeric vector of predefined parameter values
or a logical (for |
scaleparm |
a logical indicating if (internal) scaling shall be applied to the model parameters. |
optim |
a list of optimisers as returned by |
args |
a list of arguments for |
dofit |
logical; parameters are fitted by default, otherwise a list with log-likelihood and score function is returned. |
domargins |
logical; all model parameters are fitted by default, including the parameters of marginal models. |
object |
an object of class |
newdata |
an optional data.frame coefficients and predictions shall be computed for. |
type |
type of coefficient or prediction to be returned. |
margins |
indices defining marginal models to be evaluated. Can be
single integers giving the marginal distribution of the corresponding
variable, or multiple integers (currently only |
log |
logical; return log-probabilities or log-densities if
|
nsim |
number of samples to generate. |
seed |
optional seed for the random number generator. |
K |
number of grid points to generate. |
parm |
parameter vector. |
w |
weights. |
The function implements core functionality for fitting multivariate conditional transformation models as described by \bibcitetmlt::Klein:Hothorn:Barbanti:2020.
An object of class mmlt with coef and predict
methods.
The model is always parameterised in terms of a unit lower-triangular matrix
\Lambda. If conditional = FALSE (the default), it is standardised to a
lower-triangular matrix \Omega = \Lambda \text{diag}(\Lambda^{-1}
\Lambda^{-\top}) such that \Sigma = \Omega^{-1} \Omega^{-\top} is a
correlation matrix. Note that Omega = \Lambda when conditional =
TRUE was requested. These concepts are explained in
\bibcitetmlt::hothorn_2024, Section 2.
*
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.