| mlt-package | R Documentation |
The mlt package implements maximum likelihood estimation in conditional transformation models as introduced by \bibcitetmlt::Hothorn:Moest:Buehlmann:2017, its multivariate extension by \bibcitetmlt::Klein:Hothorn:Barbanti:2020, and location-scale models by \bibcitetSiegfried_Kook_Hothorn_2023.
An introduction to the package is available in the mlt package
vignette from package mlt.docreg \bibcitepmlt::Hothorn:2018.
Novice users might find the high(er) level interfaces offered by package tram more convenient.
*
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.