Learn R Programming

mlt (version 1.7-4)

mlt-package: General Information on the mlt Package

Description

The mlt package implements maximum likelihood estimation in conditional transformation models as introduced by mlt::Hothorn:Moest:Buehlmann:2017, its multivariate extension by mlt::Klein:Hothorn:Barbanti:2020, and location-scale models by Siegfried_Kook_Hothorn_2023.

An introduction to the package is available in the mlt package vignette from package mlt.docreg mlt::Hothorn:2018.

Novice users might find the high(er) level interfaces offered by package tram more convenient.

Arguments

References

*